summaryrefslogtreecommitdiffstats
path: root/src/knutmainwindow.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/knutmainwindow.cpp')
-rw-r--r--src/knutmainwindow.cpp28
1 files changed, 14 insertions, 14 deletions
diff --git a/src/knutmainwindow.cpp b/src/knutmainwindow.cpp
index 5b1aa49..363762a 100644
--- a/src/knutmainwindow.cpp
+++ b/src/knutmainwindow.cpp
@@ -29,12 +29,12 @@
#include <tqfont.h>
-#include <tqpalette.h>
-#include <tqbrush.h>
+#include <palette.h>
+#include <brush.h>
#include <tqcolor.h>
#include <tqstring.h>
#include <tqscrollview.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqiconset.h>
#include <tqstring.h>
#include <tqstringlist.h>
@@ -150,7 +150,7 @@ void KNutMainWindow::addComboStatusItem (const TQString text, const TQString nam
if (m_infoCombo->count() >= (int)knc::maxCountKNutEvent) m_infoCombo->removeItem(0);
if (m_listKNutEvent->count() > knc::maxCountKNutEvent) m_listKNutEvent->remove(m_listKNutEvent->begin());
- TQString dateTime(TQDate::tqcurrentDate().toString());
+ TQString dateTime(TQDate::currentDate().toString());
dateTime +=" " + TQTime::currentTime().toString();
if (name.isEmpty()) {
m_infoCombo->insertItem(dateTime+" "+text);
@@ -195,14 +195,14 @@ void KNutMainWindow::setConfig (unsigned int changeSetting) {
if (!m_settingData->customBColor) { // nastavime barvu pozadi podle systemu
m_area->setPalette (m_mainPalette); // we set background color based on system
m_panelMeter->setPalette (m_mainPalette);
- tqrepaint();
+ repaint();
}
else {
m_areaPalette.setColor(TQPalette::Active,TQColorGroup::Background,m_settingData->mainBackgroundColor);
m_areaPalette.setColor(TQPalette::Inactive,TQColorGroup::Background,m_settingData->mainBackgroundColor);
m_area->setPalette (m_areaPalette);
m_panelMeter->setPalette (m_areaPalette);
- tqrepaint();
+ repaint();
}
}
else {
@@ -211,7 +211,7 @@ void KNutMainWindow::setConfig (unsigned int changeSetting) {
m_areaPalette.setColor(TQPalette::Inactive,TQColorGroup::Background,m_settingData->mainBackgroundColor);
m_area->setPalette (m_areaPalette);
m_panelMeter->setPalette (m_areaPalette);
- tqrepaint();
+ repaint();
}
}
@@ -369,7 +369,7 @@ void KNutMainWindow::showUpsData (void) {
int runtimeVal;
TQString nutStringVar;
bool okFloat;
-// activeUpsInfo->oldtqStatus=KNutNet::inittqStatus;
+// activeUpsInfo->oldStatus=KNutNet::initStatus;
// Nastaveni nemenych dat jsou precteny pouze jednou, predpoklada se jejich nemenost
// setting of unchange data, ones are reading only one.
@@ -414,9 +414,9 @@ void KNutMainWindow::showUpsData (void) {
m_existLowHighXfer = true;
}
}
- int upstqStatus=0;
- if ((upstqStatus = m_activeUpsInfo->upsNet->readtqStatus ()) != -1)
- m_frontPanel->setPanel(upstqStatus);
+ int upsStatus=0;
+ if ((upsStatus = m_activeUpsInfo->upsNet->readStatus ()) != -1)
+ m_frontPanel->setPanel(upsStatus);
if ( !m_activeUpsInfo->upsNet->existName(m_activeUpsInfo->runtimeVar)) {
nutStringVar = m_activeUpsInfo->upsNet->readStringVar(m_activeUpsInfo->runtimeVar);
@@ -456,7 +456,7 @@ void KNutMainWindow::showUpsData (void) {
m_panelMeter->setSize(true);
//qDebug ("KNutMainWindow::showUpsData 3");
m_mainSplit->refresh();
// doesn't tqrepaint analog pointers, because pointers will be repainted twice
//qDebug ("KNutMainWindow::showUpsData 4");
// repaintAnalogs(false); // don't make this
//qDebug ("KNutMainWindow::showUpsData 5");
@@ -494,7 +494,7 @@ void KNutMainWindow::repaintPanel (void) {
}
else m_frontPanel->setRuntime(knc::numberVarError);
// precteme status a nastavime zarovky panelu
- int status = m_activeUpsInfo->upsNet->readtqStatus();
+ int status = m_activeUpsInfo->upsNet->readStatus();
m_frontPanel->setPanel(status);
}
@@ -727,7 +727,7 @@ void KNutMainWindow::initToolBar ( void ) {
TQLabel *upsNazev = new TQLabel ("UPS : ",toolBar("mainToolBar"));
// upsNazev is connected on toolBaar, dosn't need to call desctructor
- toolBar ("mainToolBar")->insertWidget (0,upsNazev->tqsizeHint().width(),upsNazev);
+ toolBar ("mainToolBar")->insertWidget (0,upsNazev->sizeHint().width(),upsNazev);
toolBar ("mainToolBar")->insertCombo("",1,false, TQT_SIGNAL (activated (const TQString &)),TQT_TQOBJECT(this), TQT_SLOT (slotChangeUPS (const TQString &)));
// bude se pouze vybirat-------------------^^^
KComboBox *combo = toolBar("mainToolBar")->getCombo(1);
@@ -456,7 +456,7 @@ void KNutMainWindow::showUpsData (void) {
//qDebug ("KNutMainWindow::showUpsData 3");
m_mainSplit->refresh();
- // doesn't tqrepaint analog pointers, because pointers will be repainted twice
+ // doesn't repaint analog pointers, because pointers will be repainted twice
//qDebug ("KNutMainWindow::showUpsData 4");
// repaintAnalogs(false); // don't make this